summaryrefslogtreecommitdiff
diff options
context:
space:
mode:
authorMarkus Mohrhard <markus.mohrhard@googlemail.com>2012-12-26 19:57:34 +0100
committerMarkus Mohrhard <markus.mohrhard@googlemail.com>2012-12-26 20:01:00 +0100
commit9e41982ac165092ed024b8ab318eedc7fcf4c6a9 (patch)
treea98b830fc3c6f63fc8db9a29e760eea398098e2b
parenta6077f6d7e79c4aeba59c749da21319fe0256d57 (diff)
text:p is not allowed for chart objects, fdo#58571
Change-Id: I24c485d31ea3f0540164ff65074b392be1e557e6
-rw-r--r--xmloff/source/draw/shapeexport2.cxx8
1 files changed, 6 insertions, 2 deletions
diff --git a/xmloff/source/draw/shapeexport2.cxx b/xmloff/source/draw/shapeexport2.cxx
index d4f1e2385783..2ebd96a244f5 100644
--- a/xmloff/source/draw/shapeexport2.cxx
+++ b/xmloff/source/draw/shapeexport2.cxx
@@ -1662,8 +1662,12 @@ void XMLShapeExport::ImpExportOLE2Shape(
if( !sClassId.isEmpty() )
mrExport.AddAttribute(XML_NAMESPACE_DRAW, XML_CLASS_ID, sClassId );
- // #i118485# Add text export, the draw OLE shape allows text now
- ImpExportText( xShape );
+ if(eShapeType != XmlShapeTypePresChartShape && eShapeType != XmlShapeTypeDrawChartShape)
+ {
+ // #i118485# Add text export, the draw OLE shape allows text now
+ // fdo#58571 chart objects don't allow text:p
+ ImpExportText( xShape );
+ }
if(!bExportEmbedded)
{